@@ -9,13 +9,20 @@ from .models import *
 
 logger = get_task_logger(__name__)
 
-def chunks(l, n):
-    return [l[i:i+n] for i in range(0, len(l), n)]
+def chunks(d, n):
+    allout = []
+    temp = {}
+    for k in d:
+        if len(temp) == n:
+            allout.append(temp)
+            temp = {}
+        temp[k] = d[k]
+    return allout
 
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = group(addLemmas.si(x) for x in chunks(lemmas,10000))
+    lemma_job = group(addLemmas.si(x) for x in chunks(list(lemmas),10000))
     wfs,spells,trans = loadWF()
     wf_job = group(addWFS.si(x) for x in chunks(wfs,10000))
     spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
